@@ -550,6 +550,7 @@ class Interstitial(Defect):
                 {el:valence} form
             radii: Radii of elemnts in the structure
             site_type: "voronoi_vertex" uses voronoi nodes
+                "voronoi_edgecenter" uses voronoi polyhedra edge centers
                 "voronoi_facecenter" uses voronoi polyhedra face centers
                 Default is "voronoi_vertex"
             accuracy: Flag denoting whether to use high accuracy version 
@@ -593,14 +594,16 @@ class Interstitial(Defect):
         else:
             raise ValueError("Accuracy setting not understood.")
 
-        vor_node_sites, vor_facecenter_sites = symmetry_reduced_voronoi_nodes(
-                self._structure, self._rad_dict, high_accuracy_flag, symmetry_flag
-                )
+        vor_node_sites, vor_edgecenter_sites, vor_facecenter_sites = \
+            symmetry_reduced_voronoi_nodes(self._structure, self._rad_dict,
+                                           high_accuracy_flag, symmetry_flag)
         
         if site_type == 'voronoi_vertex':
             possible_interstitial_sites = vor_node_sites
         elif site_type == 'voronoi_facecenter':
             possible_interstitial_sites = vor_facecenter_sites
+        elif site_type == 'voronoi_edgecenter':
+            possible_interstitial_sites = vor_edgecenter_sites
         else:
             raise ValueError("Input site type not implemented")
 
@@ -1368,12 +1371,13 @@ def symmetry_reduced_voronoi_nodes(
 
     if not symm_flag:
         if not high_accuracy_flag:
-            vor_node_struct, vor_facecenter_struct  = get_voronoi_nodes(
-                        structure, rad_dict)
-            return vor_node_struct.sites, vor_facecenter_struct.sites
+            vor_node_struct, vor_edgecenter_struct, vor_facecenter_struct = \
+                get_voronoi_nodes(structure, rad_dict)
+            return vor_node_struct.sites, vor_edgecenter_struct.sites, \
+                   vor_facecenter_struct.sites
         else:
             # Only the nodes are from high accuracy voronoi decomposition
-            vor_node_struct, vor_facecenter_struct  = \
+            vor_node_struct, vor_edgecenter_struct, vor_facecenter_struct  = \
                     get_high_accuracy_voronoi_nodes(structure, rad_dict)
             # Before getting the symmetry, remove the duplicates
             vor_node_struct.sites.sort(key = lambda site: site.voronoi_radius)
@@ -1381,10 +1385,9 @@ def symmetry_reduced_voronoi_nodes(
             dist_sites = filter(check_not_duplicates, vor_node_struct.sites)
             return dist_sites, vor_facecenter_struct.sites
 
-
     if not high_accuracy_flag:
-        vor_node_struct, vor_facecenter_struct  = get_voronoi_nodes(
-                        structure, rad_dict)
+        vor_node_struct, vor_edgecenter_struct, vor_facecenter_struct = \
+            get_voronoi_nodes(structure, rad_dict)
         vor_node_symmetry_finder = SymmetryFinder(vor_node_struct, symprec=1e-1)
         vor_node_symm_struct = vor_node_symmetry_finder.get_symmetrized_structure()
         node_equiv_sites_list = vor_node_symm_struct.equivalent_sites
@@ -1393,6 +1396,17 @@ def symmetry_reduced_voronoi_nodes(
         for equiv_sites in node_equiv_sites_list:
             add_closest_equiv_site(node_dist_sites, equiv_sites)
 
+        vor_edge_symmetry_finder = SymmetryFinder(
+            vor_edgecenter_struct, symprec=1e-1)
+        vor_edge_symm_struct = vor_edge_symmetry_finder.get_symmetrized_structure()
+        edgecenter_equiv_sites_list = vor_edge_symm_struct.equivalent_sites
+
+        edgecenter_dist_sites = []
+        for equiv_sites in edgecenter_equiv_sites_list:
+            add_closest_equiv_site(edgecenter_dist_sites, equiv_sites)
+        if not edgecenter_equiv_sites_list:     # Fix this so doesn't arise
+            edgecenter_dist_sites = vor_edgecenter_struct.sites
+
         vor_fc_symmetry_finder = SymmetryFinder(
                         vor_facecenter_struct, symprec=1e-1)
         vor_fc_symm_struct = vor_fc_symmetry_finder.get_symmetrized_structure()
@@ -1404,10 +1418,10 @@ def symmetry_reduced_voronoi_nodes(
         if not facecenter_equiv_sites_list:     # Fix this so doesn't arise
             facecenter_dist_sites = vor_facecenter_struct.sites
 
-        return node_dist_sites, facecenter_dist_sites
+        return node_dist_sites, edgecenter_dist_sites, facecenter_dist_sites
     else:
         # Only the nodes are from high accuracy voronoi decomposition
-        vor_node_struct, vor_facecenter_struct  = \
+        vor_node_struct, vor_edgecenter_struct, vor_facecenter_struct = \
                 get_high_accuracy_voronoi_nodes(structure, rad_dict)
 
         # Before getting the symmetry, remove the duplicates
@@ -1427,9 +1441,19 @@ def symmetry_reduced_voronoi_nodes(
             else:
                 i = i+1
 
-
         node_dist_sites = dist_sites
 
+        vor_edge_symmetry_finder = SymmetryFinder(
+            vor_edgecenter_struct, symprec=1e-1)
+        vor_edge_symm_struct = vor_edge_symmetry_finder.get_symmetrized_structure()
+        edgecenter_equiv_sites_list = vor_edge_symm_struct.equivalent_sites
+
+        edgecenter_dist_sites = []
+        for equiv_sites in edgecenter_equiv_sites_list:
+            add_closest_equiv_site(edgecenter_dist_sites, equiv_sites)
+        if not edgecenter_equiv_sites_list:     # Fix this so doesn't arise
+            edgecenter_dist_sites = vor_edgecenter_struct.sites
+
         vor_fc_symmetry_finder = SymmetryFinder(
                         vor_facecenter_struct, symprec=1e-1)
         vor_fc_symm_struct = vor_fc_symmetry_finder.get_symmetrized_structure()
@@ -1441,4 +1465,4 @@ def symmetry_reduced_voronoi_nodes(
         if not facecenter_equiv_sites_list:     # Fix this so doesn't arise
             facecenter_dist_sites = vor_facecenter_struct.sites
 
-        return node_dist_sites, facecenter_dist_sites
+        return node_dist_sites, edgecenter_dist_sites, facecenter_dist_sites
