@@ -366,7 +366,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
         mAh = (step2["evolution"] - step1["evolution"]) \
             * Charge(1, "e").to("C") * Time(1, "s").to("h") * AVOGADROS_CONST\
             * 1000
-        licomp = Composition.from_formula(working_ion)
+        licomp = Composition(working_ion)
         prev_rxn = step1["reaction"]
         reactants = {comp: abs(prev_rxn.get_coeff(comp))
                      for comp in prev_rxn.products if comp != licomp}
@@ -377,7 +377,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
 
         reactants[licomp] = (step2["evolution"] - step1["evolution"])
 
-        rxn = BalancedReaction(reactants, products, remove_spectator_species=True)
+        rxn = BalancedReaction(reactants, products)
 
         for el, amt in normalization_els.items():
             if rxn.get_el_amount(el) > 1e-6:
