@@ -832,19 +832,23 @@ class StructureInteractorStyle(vtk.vtkInteractorStyleTrackballCamera):
 
 
 def make_movie(structures, output_filename="movie.mp4", zoom=1.0, fps=20,
-               bitrate="10000k", quality=1):
+               bitrate="10000k", quality=1, **kwargs):
     """
     Generate a movie from a sequence of structures using vtk and ffmpeg.
 
     Args:
-        structures: sequence of structures
-        output_filename: filename for structure output. defaults to movie.mp4
-        zoom: A zoom to be applied to the visualizer. Defaults to 1.0.
-        fps: Frames per second for the movie. Defaults to 20.
-        bitrate: Video bitate.  Defaults to 10000k (fairly high quality).
-        quality: A quality scale. Defaults to 1.
+        structures ([Structure]): sequence of structures
+        output_filename (str): filename for structure output. defaults to
+            movie.mp4
+        zoom (float): A zoom to be applied to the visualizer. Defaults to 1.0.
+        fps (int): Frames per second for the movie. Defaults to 20.
+        bitrate (str): Video bitate.  Defaults to "10000k" (fairly high
+            quality).
+        quality (int): A quality scale. Defaults to 1.
+        \*\*kwargs: Any kwargs supported by StructureVis to modify the images
+            generated.
     """
-    vis = StructureVis()
+    vis = StructureVis(**kwargs)
     vis.show_help = False
     vis.redraw()
     vis.zoom(zoom)
@@ -855,6 +859,6 @@ def make_movie(structures, output_filename="movie.mp4", zoom=1.0, fps=20,
         vis.write_image(filename.format(i), 3)
     filename = "image%0" + str(sigfig) + "d.png"
     args = ["ffmpeg", "-y", "-i", filename,
-            "-qscale", str(quality), "-r", str(fps), "-b", str(bitrate),
+            "-q:v", str(quality), "-r", str(fps), "-b:v", str(bitrate),
             output_filename]
     subprocess.Popen(args)
